@@ -12,6 +12,9 @@ from .callService import callService, callGetService, callPostService, callPutSe
 from .pythonObjCompare import objectsEqual
 from .assertMultiLineStringsEqual import areMultiLinesStringsEqual, assertMultiLineStringsEqual
 
+#Exceptions
+from .pythonObjCompare import DataObjectToComplexToCompare
+
 from ._version import get_versions
 __version__ = get_versions()['version']
 del get_versions
